@@ -1,9 +1,8 @@
-from sys import path, argv
-from os import getcwd
 from os import environ
+from sys import argv
 
 from setux.targets import Local, SSH
-
+from setux.main.logger import debug
 from setux.repl import commands
 from setux.repl.repl import repl, prompt
 from .usage import usage
@@ -22,8 +21,6 @@ def get_target(name=None):
 
 
 def main():
-    path.insert(0, getcwd())
-
     if len(argv)>1:
         name = argv[1]
         if name in ('usage', 'help', '?'): return usage()
@@ -41,8 +38,10 @@ def main():
         if not target:
             target = get_target()
         args = ' '.join(args)
+        debug(f'{name} {target} {args}')
         print(f'{prompt(target)}{args}')
         cmd(target, args)
     else:
         target = get_target(argv[1] if len(argv)>1 else None)
+        debug(f'repl {target}')
         repl(target)
